@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -11,7 +11,7 @@
 #define DPMI_VERSION   		0x00	/* major version 0 */
 #define DPMI_DRIVER_VERSION	0x5a	/* minor version 0.90 */
 
-#define DPMI_MAX_CLIENTS	8	/* maximal number of clients */
+#define DPMI_MAX_CLIENTS	32	/* maximal number of clients */
 
 #define DPMI_page_size		4096	/* 4096 bytes per page */
 
@@ -31,10 +31,6 @@
 #define UCODESEL 0x23
 #define UDATASEL 0x2b
 #endif
-#ifdef __NetBSD__
-#define	UCODESEL GSEL(GUCODE_SEL, SEL_UPL)
-#define	UDATASEL GSEL(GUDATA_SEL, SEL_UPL)
-#endif
 
 EXTERN int in_dpmi INIT(0);        /* Set to 1 when running under DPMI */
 #define current_client (in_dpmi-1)
@@ -50,9 +46,6 @@ void dpmi_get_entry_point();
 #ifdef __linux__
 void dpmi_fault(struct sigcontext_struct *);
 #endif
-#ifdef __NetBSD__
-void dpmi_fault(struct sigcontext *, int);
-#endif
 void dpmi_realmode_hlt(unsigned char *);
 void run_pm_int(int);
 void run_pm_mouse();
