@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -79,13 +79,12 @@ __asm__("___START___: jmp _emulate\n");
 #ifdef __linux__
 #if GLIBC_VERSION_CODE >= 2000
 #include <sys/vt.h>
-#include <sys/kd.h>
 #else
-#include <linux/vt.h>
-#include <linux/kd.h>
+#include "Linux/vt.h"
 #endif
-#include <linux/fd.h>
-#include <linux/hdreg.h>
+#include <sys/kd.h>
+#include "Linux/fd.h"
+#include "Linux/hdreg.h"
 #include <sys/vm86.h>
 #include <syscall.h>
 #endif
@@ -321,7 +320,7 @@ static void do_liability_disclaimer_prompt(void)
   char buf[32];
   char disclaimer_file_name[256];
   static char text[] ="
-  The Linux DOSEMU, Copyright (C) 2000 the 'DOSEMU-Development-Team'.
+  The Linux DOSEMU, Copyright (C) 2001 the 'DOSEMU-Development-Team'.
   This program is  distributed  in  the  hope that it will be useful,
   but  WITHOUT  ANY  WARRANTY;   without even the implied warranty of
   MERCHANTABILITY  or  FITNESS FOR A PARTICULAR PURPOSE. See the file
@@ -383,6 +382,7 @@ emulate(int argc, char **argv)
 #endif
 {
     extern void parse_dosemu_users(void);
+    extern void secure_option_preparse(int *argc, char **argv);
     int e;
 
     srand(time(NULL));
@@ -400,6 +400,12 @@ emulate(int argc, char **argv)
     /* NOW! it is safe to touch the priv code.  */
     priv_init();  /* This must come first! */
 
+    /* Before we even try to give options to the parser,
+     * we pre-filter some dangerous options and delete them
+     * from the arguments list
+     */
+    secure_option_preparse(&argc, argv);
+
     /* This has to come next:
      * Parse dosemu.users _before_ any argument usage to catch
      * a not allowed user playing with overruns and kick him out
