@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -8,11 +8,7 @@
 #define _EMU_IODEV_H
 
 #include <features.h>
-#if GLIBC_VERSION_CODE >= 2000
 #include <sys/time.h>
-#else
-#include <linux/time.h>
-#endif
 #if 0
 #include "emu_defs.h"
 #include "keyb.h"
